<?php
/* ---------------------------------------------------------------------------
Title: FlickrSSP 1.6
Author: Brian Sweeting (http://www.sweeting.net/)

FlickrSSP allows you to use Flickr (http://www.flickr.com) and SlideshowPro 
(http://www.slideshowpro.net) to display all of your Flickr photosets on 
your own website instead of just your recent photos via the RSS feed.

Modifications by Stephen Paul Weber
--------------------------------------------------------------------------- */

class FlickrSSP {

	var $flickrssp_version;
	var $flickr_api_url;
	var $config = array();
	var $data = array();
	var $error = array();
	
	
	function flickrssp($config,$photosets=null) {

		
		$this->flickrssp_version = '1.6';

		// Set configuration parameters
		$this->config = $config;
		$this->config['service'] = $config['service'] ? $config['service'] : 'flickr';
		
		// Check to see if specific photosets are to be retrieved.
		if(is_null($photosets)) { 
			$this->config['photosets'] = null; 
		}
		else {
			eregi_replace(' ','',$photosets);
			$this->config['photosets'] = explode(',',$photosets);
		}

		// Get the xml and return it
		$this->getXml();

		return;

	}


	function getXml() {

		//Check to see if xml file exists, if not attempt to create it
		if(file_exists($this->config['xml'])) {

			// Return the content of the XML file if no update is needed
			if((time() - filemtime($this->config['xml'])) <= $this->config['cache_period'] && filesize($this->config['xml'])>1024) {
				$this->displayXml();
			}
			else { 
				$this->updateXml();
			}
		}
		else {
			$this->updateXml();
		}

		return;

	}
	
	
	function updateXml() {
           if($this->config['service'] == 'flickr') $xml = $this->updateXmlFlickr();
           if($this->config['service'] == 'riya') $xml = $this->updateXmlRiya();
           if($this->config['service'] == 'picasa') $xml = $this->updateXmlPicasa();
           if($this->config['service'] == 'all') $xml = $this->updateXmlFlickr().$this->updateXmlRiya().$this->updateXmlPicasa();

		// Begin SlideShowPro xml String
		$xml = '<?xml version="1.0" encoding="UTF-8"?>'."\n".'<!-- Generated by meyshanside '.$this->flickrssp_version.' (http://www.spicyexpress.net/mslide/meyshanside) -->'."\n".'<gallery>'."\n" . $xml;
   	        $xml .= '</gallery>'."\n";

           if(!$xml) {$this->displayXml(); return;}
		// Write the XML file
		if($w = @fopen($this->config['xml'],'wb')) {
			fwrite($w,$xml);
			fclose($w);
		}
		else {
			$this->error[] = 'Could not save the XML file';
		}
		
		// Get the xml and return it
		$this->displayXml();
	}

        function updateXmlPicasa() {
           require_once 'picasa.class.php'; 
  
           $r = new PicasaWebAPI($this->config['picasa_username']);
  
           $response = $r->get_albums();

           $xml = '';

           if ( $response !== false ) {
     
             // Loop through all albums
             foreach ($response as $album) {
               // Parse album properties
               $xml .= "\t".'<album title="'.htmlspecialchars($album).'" description="" lgPath="" tn="">'."\n";
               $response2 = $r->get_album($album);
               if ( $response2 !== false ) {
     
                   // Loop through all photos in the album
                   foreach ($response2 as $photo) {
                     // Parse photo properties
                     $xml .= "\t\t".'<img src="'.htmlspecialchars($photo).'" link="'.htmlspecialchars($photo).'" tn="" caption="" />'."\n";
                   }
    
                 } else {
    
                   $xml .= 'ERROR';
    
                 }
               $xml .= "\t".'</album>'."\n";
             }
    
           } else {
    
                   $xml .= 'ERROR';
    
           }


           return $xml;

        }//end update xml picasa


        function updateXmlRiya() {
           require_once 'riyaapi.class.php'; 
  
           $r = new RiyaAPI();  
  
           $r->setApiKey($this->config['riya_api_key']);
           $r->setUsername($this->config['riya_username']);
           $r->setAuthToken($r->getAuthToken($this->config['riya_password']));
  
           $response = $r->callMethod('riya.albums.GetAlbums');
 
           $xml = '';

           if ( $response !== false ) {
     
             // Loop through all albums
             foreach ($response->albums->album as $album) {
               // Parse album properties
               $properties = RiyaApi::parseAttributes($album);
               $xml .= "\t".'<album title="'.htmlspecialchars($properties['name']).'" description="" lgPath="" tn="'.htmlspecialchars($properties['thumbnail']).'">'."\n";
               $response2 = $r->callMethod('riya.albums.GetPhotosInAlbum', array('album_id' => $properties['id']));
               if ( $response2 !== false ) {
     
                   // Loop through all photos in the album
                   foreach ($response2->album->photo as $photo) {
                     // Parse photo properties
                     $properties2 = RiyaApi::parseAttributes($photo);
                     $xml .= "\t\t".'<img src="'.htmlspecialchars($properties2['screenres']).'" link="'.htmlspecialchars($properties2['screenres']).'" tn="'.htmlspecialchars($properties2['thumbnail']).'" caption="" />'."\n";
                   }
    
                 } else {
    
                   $xml .= 'Error Code: ' . $r->getErrorCode() . '<br />';
                   $xml.= 'Error Message: ' . $r->getErrorMessage() . '<br />';
    
                 }
               $xml .= "\t".'</album>'."\n";
             }
    
           } else {
    
             $xml .= 'Error Code: ' . $r->getErrorCode() . '<br />';
             $xml .= 'Error Message: ' . $r->getErrorMessage() . '<br />';
    
           }


           return $xml;

        }//end update xml riya

        function updateXmlFlickr() {
		require_once('phpFlickr/phpFlickr.php');
		$f = new phpFlickr($this->config['flickr_api_key']);
		
		// Enable caching of Flickr calls
		if($this->config['cache_path']!='') {
		  $f->enableCache("fs", $this->config['cache_path'], $this->config['cache_period']);	
	  }

		// Find the NSID of the username
		$this->config['tokens'] = $f->people_findByUsername($this->config['flickr_username']);

		// Get the friendly URL of the user's photos
		$this->config['photos_url'] = $f->urls_getUserPhotos($this->config['tokens']['nsid']);

           $xml = '';

		// Get Photosets
		if(is_null($this->config['photosets'])) { 
			// Get all of the user's photosets
			$this->data['photosets'] = $f->photosets_getList($this->config['tokens']['nsid']);
		}
		else {
			// Get only specified photosets
			for($i=0; $i<sizeof($this->config['photosets']); $i++) {
				$this->data['photosets']['photoset'][] = $f->photosets_getInfo($this->config['photosets'][$i]);
			}
		}

		if(!is_array($this->data['photosets'])) {
			$this->error[] = 'There are no photosets for this user';
		}
		else {
		
			// Loop through each photoset
			foreach ($this->data['photosets']['photoset'] as $photoset) {

				// Create XML tag of the album
				$xml .= "\t".'<album title="'.$photoset['title'].'" description="'.$photoset['description'].'" lgPath="" tn="http://static.flickr.com/'.$photoset['server'].'/'.$photoset['primary'].'_'.$photoset['secret'].'_s.jpg">'."\n";

				//Get photos for this photoset
				$this->data['photos'][$photoset['id']] = $f->photosets_getPhotos($photoset['id']);
				
				if(!is_array($this->data['photos'][$photoset['id']])) {
					$this->error[] = 'There are no photos in this photoset';
				}
				else {

					// Loop through each photo in the photoset
					foreach($this->data['photos'][$photoset['id']]['photo'] as $photo) {

						// Create XML tag for each image of the photoset
						$xml .= "\t\t".'<img src="http://static.flickr.com/'.$photo['server'].'/'.$photo['id'].'_'.$photo['secret'].'.jpg" link="'.$this->config['photos_url'].$photo['id'].'" tn="http://static.flickr.com/'.$photo['server'].'/'.$photo['id'].'_'.$photo['secret'].'_t.jpg" caption="'.$photo['title'].'" />'."\n";

					}
				
				}
				
				$xml .= "\t".'</album>'."\n";

			}
			
		
		}


              return $xml;

	}
	
	
	function displayXml() {
		
		// If there were errors display them
		if(sizeof($this->error)>0) {
			$this->displayErrors();
		}

		@header('Content-type: text/plain');
		$xml = file_get_contents($this->config['xml']);
		echo $xml;
		return;
        }
	
	
	function displayErrors() {

		@header('Content-type: text/html');
		echo '<ul>'."\n";
		for($i=0; $i<sizeof($this->error); $i++) {
			echo '<li>'.$this->error[$i].'</li>'."\n";
		}
		echo '</ul>'."\n";
		exit;

	}
	
}
?>